import {sliderTop} from 'd3-simple-slider';
import {createStructuredSelector} from 'reselect';

import {link} from 'ui/lib/d3-redux';

import {getGraphCursorOffset} from 'ml/selectors/hydrograph-state-selector';

import {setGraphCursorOffset} from 'ml/store/hydrograph-state';

import {getMainXScale} from './selectors/scales';
import {getMainLayout} from './selectors/layout';



/*
 * Renders the cursor slider and sets up the redux event handlers to update the slider
 * when needed.
 * @param {D3 selection} svg
 * @param {Redux store} store
 */
export const drawCursorSlider = function(svg, store) {
    const slider = sliderTop()
        .displayValue(false)
        .ticks(0);

    svg.append('g')
        .attr('class', 'cursor-slider-group')
        .attr('ga-on', 'click')
        .attr('ga-event-category', 'hydrograph-interaction')
        .attr('ga-event-action', 'clickOnSlider')
        .call(link(store, (group, {xScale, layout}, store ) => {
            const [startMillis, endMillis] = xScale.domain();
            const [startX, endX] = xScale.range();
            const cursorOffset = getGraphCursorOffset(store.getState());

            slider
                .min(startMillis)
                .max(endMillis)
                .width(endX - startX);
            slider.silentValue(cursorOffset ? slider.min() + cursorOffset : slider.max());

            group
                .attr('transform', `translate(${layout.margin.left},15)`)
                .call(slider);
            slider.on('onchange', (val) => {
                store.dispatch(setGraphCursorOffset(val - startMillis));
            });
        }, createStructuredSelector({
            xScale: getMainXScale('current'),
            layout: getMainLayout
        }), store))
        .call(link(store, (group, cursorOffset) => {
            slider.silentValue(cursorOffset ? slider.min() + cursorOffset : slider.max());
        }, getGraphCursorOffset));
};

